@@ -145,7 +145,7 @@ void NotesManager::slotCheckAlarm()
 
     Akonadi::Item::List lst;
     Q_FOREACH (const Akonadi::Item &item, mListItem) {
-        NoteShared::NoteAlarmAttribute *attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
+        const NoteShared::NoteAlarmAttribute *attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
         if (attrAlarm) {
             if (attrAlarm->dateTime() < QDateTime::currentDateTime()) {
                 lst.append(item);
